@@ -1,22 +1,11 @@
 import numpy as np
 import tensorflow as tf
 from tensorflow.keras import Model
-from tensorflow.keras.layers import (
-    Add,
-    BatchNormalization,
-    Concatenate,
-    Conv2D,
-    Input,
-    Lambda,
-    LeakyReLU,
-    MaxPool2D,
-    UpSampling2D,
-    ZeroPadding2D,
-)
-from tensorflow.keras.losses import (
-    binary_crossentropy,
-    sparse_categorical_crossentropy,
-)
+from tensorflow.keras.layers import (Add, BatchNormalization, Concatenate,
+                                     Conv2D, Input, Lambda, LeakyReLU,
+                                     MaxPool2D, UpSampling2D, ZeroPadding2D)
+from tensorflow.keras.losses import (binary_crossentropy,
+                                     sparse_categorical_crossentropy)
 from tensorflow.keras.regularizers import l2
 
 from .utils import broadcast_iou
